# Anaplan SDK

--- Anaplan SDK is an independent, unofficial project providing pythonic access to the [Anaplan Integration API v2](https://anaplan.docs.apiary.io/). This Project aims to provide high-level abstractions over the API, so you can deal with python objects and simple functions rather than implementation details like HTTP Requests, Authentication, JSON Parsing, Compression, Chunking and so on. This Projects supports the [Bulk API](https://help.anaplan.com/use-the-bulk-apis-93218e5e-00e5-406e-8361-09ab861889a7), the [Transactional API](https://help.anaplan.com/use-the-transactional-apis-cc1c1e91-39fc-4272-a4b5-16bc91e9c313) and the [ALM API](https://help.anaplan.com/application-lifecycle-management-api-2565cfa6-e0c2-4e24-884e-d0df957184d6), providing both synchronous and asynchronous Clients. --- Head over to the [Quick Start](quickstart.md) to get started with the basics.